@@ -1,8 +1,5 @@
-from owlready2 import get_ontology
-from lnn import Model, Predicate, Variable, World, Implies, Not
-import tqdm
-import fastobo
 import pyhornedowl
+from lnn import Implies, Model, Predicate, Variable, World
 
 
 def get_name(iri: str):
